<?php 
/**
 * @file
 * Pie chart.
 * Displays a chart containing donation totals broken out by source.
 */

// create the ctools plugin
$plugin = array(
  'single'              => TRUE, 
  'title'               => t('Donations by Source: Other Sources'), 
  'description'         => t('Displays a chart showing a breakdown of other sources people have donated to who have donated to this source.'),
  'category'            => t('CRM Core Donations'),
  'edit form'           => 'crm_core_donation_source_other_sources_form', 
  'render callback'     => 'crm_core_donation_source_other_sources',
  'admin info'          => 'crm_core_donation_source_other_sources_info', 
  'defaults' => array( 
    'text' => '',
  ),
  'all contexts' => TRUE, 
);

/**
 * admin info
 */
function crm_core_donation_source_other_sources_info($subtype, $conf, $contexts) {
  if (!empty($conf)) {
    $block = new stdClass;
    $block->title = $conf['override_title'] ? $conf['override_title_text'] : '';
    $block->content = t('Other Sources');
    return $block;
  }
}

/**
 * Settings form
 */
function crm_core_donation_source_other_sources_form($form, &$form_state) {
  $conf = $form_state['conf'];
  return $form;
}
/**
 * submit handler for settings form
 */
function crm_core_donation_source_other_sources_form_submit($form, &$form_state) {
}

/**
 * Render callback
 */
function crm_core_donation_source_other_sources($subtype, $conf, $panel_args, $context = NULL) {
  
  // set up a table for displaying raw data
  $header = array('Source', 'Donors', 'Percentage');
  $rows = array();
  
  // storing information that will go into the chart
  $source_data = array();
  
  // get the total donors for this source
  $this_source = db_query("SELECT COUNT(DISTINCT field_activity_participants_target_id) AS donors
  	FROM {field_data_field_cmcd_source} fds
  		JOIN {field_data_field_activity_participants} fdp
  		ON fds.entity_id = fdp.entity_id 
  	WHERE fds.field_cmcd_source_value = :source",
    array(':source' => decode_entities($panel_args[0]))
  );  
  foreach ($this_source as $item) {
    $total_donors = $item->donors;
  }
  
  // get the other sources that people will use
  $sources = db_query("
  	SELECT 
  		fds.field_cmcd_source_value as source,
  		COUNT(DISTINCT field_activity_participants_target_id) AS total_other_donations
  	FROM {field_data_field_cmcd_source} fds
  		JOIN {field_data_field_activity_participants} fdp
  		ON fds.entity_id = fdp.entity_id 
  	WHERE fds.field_cmcd_source_value != :source
  	  AND field_activity_participants_target_id IN (
      	SELECT field_activity_participants_target_id AS id
      	FROM {field_data_field_cmcd_source} fds
      		JOIN {field_data_field_activity_participants} fdp
      		ON fds.entity_id = fdp.entity_id 
      	WHERE fds.field_cmcd_source_value = :source
  	  )
  	GROUP BY source
  	ORDER BY source",
    array(':source' => decode_entities($panel_args[0]))
  );  
  
  foreach ($sources as $row) {
    
    $percent = floor(($row->total_other_donations / $total_donors)*100) . '%';
    
    // populate the chart
    $temp = new flotData(array( array(0, $row->total_other_donations)) );
    $temp->label = $row->source;
    $source_data[] = $temp;
    
    // output the rows for the table
    $rows[] = array(
      'data' => array(
        $row->source, $row->total_other_donations, $percent
      ),
    );
  }
  
  // set up the chart
  $options = new flotStylePie();
  $options->series->pie->radius = 1;
  $options->series->pie->innerRadius = 0.6;
  $options->series->pie->label->show = FALSE;
  $options->series->pie->label->radius = 2/3;
  $options->series->pie->label->threshold = 0.1;
  $options->series->pie->label->backgroundOpacity = 0;
  $options->legend = new stdClass();
  $options->legend->show = FALSE;
  $options->legend->position = 'bottom';
  
  // output the chart
  $content = theme('flot_graph', array( 'data' => $source_data, 'options' => $options ) );
  
  // output the table
  $content .= theme('table', array( 'rows' => $rows, 'header' => $header) );

  // return everything
  $block = new stdClass();
  $block->title = t('Other Sources');
  $block->content = $content;
  
  return $block;  
  
}








